fnss.netconfig.capacities.set_capacities_random_uniform — FNSS 0.7.0 documentation

# fnss.netconfig.capacities.set_capacities_random_uniform

`set_capacities_random_uniform`(topology, capacities, capacity_unit='Mbps')

  Set random link capacities according to a uniform probability density function.

  Parameters: | topology : Topology The topology to which link capacities will be set capacities : list A list of all possible capacity values capacity_unit : str, optional The unit in which capacity value is expressed (e.g. Mbps, Gbps etc..)